@@ -1,5 +1,10 @@
 from messageflux.iodevices.base import InputDevice, ReadResult
+
 from .message_handling_service import (BatchMessageHandlingService,
                                        MessageHandlerBase,
                                        MessageHandlingService,
                                        BatchMessageHandlerBase)
+
+from .pipeline_service import (PipelineService,
+                               PipelineResult,
+                               PipelineHandlerBase)
